<?xml version="1.0" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:template match="configurations[@name='parameter']">
		<p><b>Todo: </b>Add command to obtain the parameters to the XSL.</p>
		<p>This section shows the heater configuration parameters.</p>
		<h2>Parameters</h2>
		<table border="1">
			<tr bgcolor="#9acd32">
				<th colspan="2">Config</th>
				<th colspan="4">Present</th>
				<th colspan="3">Function</th>
				<th colspan="1"/>
			</tr>
			<tr bgcolor="#9acd32">
				<th>Type</th>
				<th>Group</th>
				<th>Code</th>
				<th>Name</th>
				<th>Description</th>
				<th>Unit</th>
				<th>Byte</th>
				<th>expression</th>
				<th>Format</th>
				<th>Limits / possible values</th>
			</tr>
			<xsl:for-each select="config">
				<xsl:sort select="function/@byte" data-type="number"/>
				<tr>
					<td>
						<xsl:value-of select="@type"/>
					</td>
					<td>
						<xsl:value-of select="@group"/>
					</td>
					<td>
						<xsl:value-of select="present/@code.txt"/>
					</td>
					<td>
						<xsl:variable name="reference1" select="present/@name.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference1]/@value"/>
					</td>
					<td>
						<xsl:variable name="reference2" select="present/@description.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference2]/@value"/>
					</td>
					<td>
						<xsl:variable name="reference3" select="present/@unit.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference3]/@value"/>
					</td>
					<td>
						<xsl:value-of select="function/@byte"/>
					</td>
					<td>
						<xsl:value-of select="function/@expression"/>
					</td>
					<td>
						<xsl:value-of select="function/@format"/>
					</td>
					<td>
						<xsl:if test="limits">
							<xsl:for-each select="limits">min: <xsl:value-of select="@min"/>, max: <xsl:value-of select="@max"/>
							</xsl:for-each>
						</xsl:if>
						<xsl:if test="node-ref">
							<xsl:variable name="node_ref" select="node-ref/@id"/>
							<xsl:for-each select="/configuration/selections[@id=$node_ref]/selection">
								<b>
									<xsl:value-of select="@value"/>
								</b>: <xsl:variable name="textual_value" select="@result.nr"/>
								<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$textual_value]/@value"/><br/>
							</xsl:for-each>
						</xsl:if>
						<xsl:if test="selections">
							<xsl:for-each select="selections/selection">
								<b>
									<xsl:value-of select="@value"/>
								</b>: <xsl:variable name="textual_value" select="@result.nr"/>
								<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$textual_value]/@value"/><br/>
							</xsl:for-each>
						</xsl:if>
					</td>
				</tr>
			</xsl:for-each>
		</table>		
	</xsl:template>

	<xsl:template match="configurations[@name='sample']">
		<h2>Sample</h2>
		<p><b>Todo: </b>Add command to obtain the sample data from the heater to the XSL.</p>
		<p>This section shows the frame that is returned from the heater. Byte 0 is actual byte 8 in the 72 byte frame returned by the heater.</p>
		<p><b>See: </b><a href="http://blog.hekkers.net/2010/10/10/more-about-the-remeha-protocol/">Link to blog.hekkers.net showing the first reverse engineering attempts</a></p>
		<table border="1">
			<tr bgcolor="#9acd32">
				<th colspan="2">Config</th>
				<th colspan="3">Present</th>
				<th colspan="3">Function</th>
				<th colspan="1"/>
			</tr>
			<tr bgcolor="#9acd32">
				<th>Type</th>
				<th>Group</th>
				<th>Name</th>
				<th>Description</th>
				<th>Unit</th>
				<th>Byte</th>
				<th>expression</th>
				<th>Format</th>
				<th>Limits / Possible values</th>
			</tr>
			<xsl:for-each select="config">
				<xsl:sort select="function/@byte" data-type="number"/>
				<tr>
					<td>
						<xsl:value-of select="@type"/>
					</td>
					<td>
						<xsl:value-of select="@group"/>
					</td>
					<td>
						<xsl:variable name="reference1" select="present/@name.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference1]/@value"/>
					</td>
					<td>
						<xsl:variable name="reference2" select="present/@description.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference2]/@value"/>
					</td>
					<td>
						<xsl:variable name="reference3" select="present/@unit.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference3]/@value"/>
					</td>
					<td>
						<xsl:value-of select="function/@byte"/>:<xsl:value-of select="function/@bit"/>
					</td>
					<td>
						<xsl:value-of select="function/@expression"/>
					</td>
					<td>
						<xsl:value-of select="function/@format"/>
					</td>
					<td>
						<xsl:if test="limits">
							<xsl:for-each select="limits">min: <xsl:value-of select="@min"/>, max: <xsl:value-of select="@max"/>
							</xsl:for-each>
						</xsl:if>
						<xsl:if test="node-ref">
							<xsl:variable name="node_ref" select="node-ref/@id"/>
							<xsl:for-each select="/configuration/selections[@id=$node_ref]/selection">
								<b>
									<xsl:value-of select="@value"/>
								</b>: <xsl:variable name="textual_value" select="@result.nr"/>
								<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$textual_value]/@value"/><br/>
							</xsl:for-each>
						</xsl:if>
						<xsl:if test="selections">
							<xsl:for-each select="selections/selection">
								<b>
									<xsl:value-of select="@value"/>
								</b>: <xsl:variable name="textual_value" select="@result.nr"/>
								<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$textual_value]/@value"/><br/>
							</xsl:for-each>
						</xsl:if>
					</td>
				</tr>
			</xsl:for-each>
		</table>		
	</xsl:template>

	<xsl:template match="configurations[@name='identification']">
		<h2>Identification</h2>
		<table border="1">
			<tr bgcolor="#9acd32">
				<th colspan="2">Config</th>
				<th colspan="3">Present</th>
				<th colspan="4">Function</th>
			</tr>
			<tr bgcolor="#9acd32">
				<th>Type</th>
				<th>Group</th>
				<th>Name</th>
				<th>Description</th>
				<th>Byte</th>
				<th>Number</th>
				<th>expression</th>
				<th>Format</th>
			</tr>
			<xsl:for-each select="config">
				<xsl:sort select="function/@byte" data-type="number"/>
				<tr>
					<td>
						<xsl:value-of select="@type"/>
					</td>
					<td>
						<xsl:value-of select="@group"/>
					</td>
					<td>
						<xsl:variable name="reference1" select="present/@name.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference1]/@value"/>
					</td>
					<td>
						<xsl:variable name="reference2" select="present/@description.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference2]/@value"/>
					</td>
					<td>
						<xsl:value-of select="function/@byte"/>
					</td>
					<td>
						<xsl:value-of select="function/@number"/>
					</td>
					<td>
						<xsl:value-of select="function/@expression"/>
					</td>
					<td>
						<xsl:value-of select="function/@format"/>
					</td>
				</tr>
			</xsl:for-each>
		</table>		
	</xsl:template>

	<xsl:template match="configurations[@name='counter']">
		<h2>Counters</h2>
		<p><b>Todo: </b>Add command to obtain the counter data from the heater to the XSL.</p>
		<p>This section shows the counter information from the heater.</p>
		<table border="1">
			<tr bgcolor="#9acd32">
				<th colspan="2">Config</th>
				<th colspan="3">Present</th>
				<th colspan="3">Function</th>
			</tr>
			<tr bgcolor="#9acd32">
				<th>Type</th>
				<th>Group</th>
				<th>Name</th>
				<th>Description</th>
				<th>Byte</th>
				<th>expression</th>
				<th>Format</th>
			</tr>
			<xsl:for-each select="config">
				<xsl:sort select="function/@byte" data-type="number"/>
				<tr>
					<td>
						<xsl:value-of select="@type"/>
					</td>
					<td>
						<xsl:value-of select="@group"/>
					</td>
					<td>
						<xsl:variable name="reference1" select="present/@name.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference1]/@value"/>
					</td>
					<td>
						<xsl:variable name="reference2" select="present/@description.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference2]/@value"/>
					</td>
					<td>
						<xsl:value-of select="function/@byte"/>
					</td>
					<td>
						<xsl:value-of select="function/@expression"/>
					</td>
					<td>
						<xsl:value-of select="function/@format"/>
					</td>
				</tr>
			</xsl:for-each>
		</table>		
	</xsl:template>

	<xsl:template match="configurations[@name='failure']">
		<h2>Failure</h2>
		<p><b>Todo: </b>Add command to obtain the failure data from the heater to the XSL.</p>
		<p>This section shows the failure information from the heater.</p>
		<table border="1">
			<tr bgcolor="#9acd32">
				<th colspan="1">Config</th>
				<th colspan="3">Present</th>
				<th colspan="3">Function</th>
				<th colspan="2"/>
			</tr>
			<tr bgcolor="#9acd32">
				<th>Type</th>
				<th>Name</th>
				<th>Description</th>
				<th>Unit</th>
				<th>Byte</th>
				<th>expression</th>
				<th>Format</th>
				<th>Limits / possible values</th>
			</tr>
			<xsl:for-each select="config">
				<xsl:sort select="function/@byte" data-type="number"/>
				<tr>
					<td>
						<xsl:value-of select="@type"/>
					</td>
					<td>
						<xsl:variable name="reference1" select="present/@name.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference1]/@value"/>
					</td>
					<td>
						<xsl:variable name="reference2" select="present/@description.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference2]/@value"/>
					</td>
					<td>
						<xsl:variable name="reference3" select="present/@unit.nr"/>
						<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$reference3]/@value"/>
					</td>
					<td>
						<xsl:value-of select="function/@byte"/>
					</td>
					<td>
						<xsl:value-of select="function/@expression"/>
					</td>
					<td>
						<xsl:value-of select="function/@format"/>
					</td>
					<td>
						<xsl:if test="limits">
							<xsl:for-each select="limits">min: <xsl:value-of select="@min"/>, max: <xsl:value-of select="@max"/>
							</xsl:for-each>
						</xsl:if>
						<xsl:if test="node-ref">
							<xsl:variable name="node_ref" select="node-ref/@id"/>
							<xsl:for-each select="/configuration/selections[@id=$node_ref]/selection">
								<b>
									<xsl:value-of select="@value"/>
								</b>: <xsl:variable name="textual_value" select="@result.nr"/>
								<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$textual_value]/@value"/><br/>
							</xsl:for-each>
						</xsl:if>
					</td>
				</tr>
			</xsl:for-each>
		</table>		
	</xsl:template>

	<xsl:template match="/">
		<html>
			<body>
				<h1>XML translation for <xsl:value-of select="/configuration/@boiler.type"/></h1>
				<p>This XSL file uses the dutch translation, if you want another language, the replace the '<b>language-nl.xml</b>' string in this file.</p>
				<p><b>Note: </b>I am not working for Remeha and I am not a heater expert, i'm an industrial software engineer.</p>
				<p>Yhis XSLT can be used to make the Recom XML configuration files in the 'config' folder more readable/easier to understand. The config files define the
				datasets used for each heater. The XSL parses the XML configuration file and each section below will contain a brief description of the content of that 
				section.</p>
				
				<h2>Properties</h2>
				<p>A few properties for the Remeha heater, it defines  the EEPROM size and version number of the firmware that corresponds with the XML file.</p>
				<table border="1">
					<tr bgcolor="#9acd32">
						<th colspan="1">Name</th>
						<th colspan="1">Value</th>
					</tr>
					<xsl:for-each select="/configuration/properties/property">
						<tr>
							<td>
								<xsl:value-of select="@name"/>
							</td>
							<td>
								<xsl:value-of select="@value"/>
							</td>
						</tr>
					</xsl:for-each>
				</table>		

				<h2>Selections (code to text transformation)</h2>
				<p>The heater returns values and codes, values are used for temperatures and codes are used for textual descriptions that correspond with a certain bit
				set in the response from the heater.</p>
				<table border="1">
					<xsl:for-each select="/configuration/selections">
						<tr bgcolor="#9acd32">
							<th colspan="2"><xsl:value-of select="@id"/></th>
						</tr>
						<tr bgcolor="#9acd32">
							<th colspan="1">Code</th>
							<th colspan="1">Value</th>
						</tr>
						<xsl:for-each select="selection">
							<tr>
								<td>
									<xsl:value-of select="@value"/>
								</td>
								<td>
									<xsl:variable name="textual_value" select="@result.nr"/>
									<xsl:value-of select="document('../language/language-nl.xml')/language/text[@id=$textual_value]/@value"/>
								</td>
							</tr>
						</xsl:for-each>
					</xsl:for-each>
				</table>		

				<!-- apply templates above -->
				<xsl:apply-templates/>
			</body>
		</html>
	</xsl:template>

</xsl:stylesheet>